Changelog
---------

Unreleased
~~~~~~~~~~

0.0.5 (2015-09-25)
~~~~~~~~~~~~~~~~~~~

- The certificates of elasticsearch hosts are now verified by default.
  [href]

- Adds completion suggestions for search-as-you-type.
  [href]

- Fixes reindex not properly working with onegov.town.
  [href]

0.0.4 (2015-09-22)
~~~~~~~~~~~~~~~~~~~

- Fixes localized mapping not working correctly in certain cases.
  [href]

- Stops the reindex command to create unwanted indices.
  [href]

- Exclude all _source fields by default.
  [href]

- Adds support for polymorphic SQLAlchemy models.
  [href]

- ORM Models now may use any name for their primary key attribute.
  [href]

0.0.3 (2015-09-18)
~~~~~~~~~~~~~~~~~~~

- No longer require elasticsearch to run when configuring the application.
  [href]

0.0.2 (2015-09-18)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to reindex all elasticsearch records.
  [href]

- Fixes a number of issues with the onegov.town integration.
  [href]

0.0.1 (2015-09-17)
~~~~~~~~~~~~~~~~~~~

- Initial Release
